@@ -276,10 +276,3 @@ ComputerScoring (int player)
   play_score (player, best);
 
 }
-
-/* Arrgh - lets all use the same tabs under emacs: 
-Local Variables:
-tab-width: 8
-c-basic-offset: 8
-indent-tabs-mode: nil
-*/
